@@ -2,5 +2,6 @@ from django.apps import AppConfig
 
 
 class EmailLogConfig(AppConfig):
-    name = 'email_log'
+    name = "email_log"
     verbose_name = "Email log"
+    default_auto_field = "django.db.models.AutoField"
