@@ -1,8 +1,9 @@
-from django.conf.urls import url
+from django.urls import path
 
 from django.contrib import admin
+
 admin.autodiscover()
 
 urlpatterns = [
-    url("admin/", admin.site.urls),
+    path("admin/", admin.site.urls),
 ]
